@@ -24,8 +24,8 @@ class PGActor(TrainableActor, ABC):
             self,
             envy: FiniteActionsRLEnvy,
             nnwrap: type(NNWrap),
-            nngraph: Optional[Union[Callable, type]]=   None,
-            seed: int=                                  123,
+            module_type: Optional[Union[Callable, type]]=   None,
+            seed: int=                                      123,
             **kwargs):
 
         TrainableActor.__init__(
@@ -43,21 +43,21 @@ class PGActor(TrainableActor, ABC):
         kwargs['num_actions'] = self._envy.num_actions()
         kwargs['observation_width'] = self._get_observation_vec(self._envy.get_observation()).shape[-1]
 
-        self.nnw: NNWrap = nnwrap(nngraph=nngraph, seed=seed, **kwargs)
+        self.nnw: NNWrap = nnwrap(module_type=module_type, seed=seed, **kwargs)
 
         self._rlog.info('*** PG_Actor *** (NN based) initialized')
         self._rlog.info(f'> NNWrap: {nnwrap.__name__}')
 
     # vectorization of observations batch, may be overridden with more optimal custom implementation
     def _get_observation_vec_batch(self, observations: List[object]) -> np.ndarray:
-        return np.array([self._get_observation_vec(v) for v in observations])
+        return np.asarray([self._get_observation_vec(v) for v in observations])
 
     @abstractmethod
     def get_policy_probs(self, observation: object) -> np.ndarray: pass
 
     # baseline, may be overridden with more optimal custom implementation
     def get_policy_probs_batch(self, observations: List[object]) -> np.ndarray:
-        return np.array([self.get_policy_probs(o) for o in observations])
+        return np.asarray([self.get_policy_probs(o) for o in observations])
 
     # gets policy action based on policy (action) probs
     def get_policy_action(self, observation: object, sampled=False) -> int:
