@@ -23,10 +23,10 @@ from typing import Optional
 
 from pypaq.pms.base_types import P_VAL, POINT, PSDD
 
-NO_REF = '___NO-REF___'
+NO_REF = '__NO-REF__'
 
 
-# Parameters Space Class
+# Parameters Space
 class PaSpa:
 
     def __init__(
@@ -40,7 +40,7 @@ class PaSpa:
         self.axes = sorted(list(self.__psdd.keys()))
         self.L2 = distance_L2
         self.dim = len(self.__psdd)
-        if self.verb>0:  print(f'\n*** PaSpa *** (dim: {self.dim}) inits')
+        if self.verb>0:  print(f'\n*** PaSpa (dim: {self.dim}) inits..')
 
         # resolve axis type and width and some safety checks
         self.__axT = {} # axis type, [list,tuple]_[float,int,diff] list_diff is not allowed
